@@ -1,7 +1,7 @@
 package Simulation::Automate::PostProcLib;
 
 use vars qw( $VERSION );
-$VERSION = "0.9.4";
+$VERSION = "0.9.6";
 
 ################################################################################
 #                                                                              #
@@ -18,7 +18,7 @@ This module contains a set of utility functions for use in the
 PostProcessors.pm module.
 This module is generic.
 
-$Id: PostProcLib.pm,v 1.2 2003/04/07 13:23:01 wim Exp $
+$Id: PostProcLib.pm,v 1.2 2003/09/04 09:54:19 wim Exp $
 
 =cut
 
@@ -43,9 +43,15 @@ use Simulation::Automate::Dictionary;
 			   %simdata
 			   $last
 			   $verylast
-			   $sweepvals
+			   $current_set_valstr
+			   $results_file
+ 			   %current_set_vals					       
+			   %sweepvals					       
+			   $sweepvals					       
 			   $sweepvar
+			   $setvar
 			   $normvar
+			   $cond
 			   $sweepvartitle
 			   $plot
 			   $interactive
@@ -61,10 +67,15 @@ use Simulation::Automate::Dictionary;
 			  $ylabel
 			  $logscale
 			  $style
+			  $xstart
+			  $xstop
+			  $ystart
+			  $ystop
+			  $xtics
+			  $ytics
 			  @results
 			  );
 
-
 ##################################################################################
 
 
@@ -83,16 +94,16 @@ You can add your own subroutine $subref to the PostProcLib.pm module.
 
 sub prepare_plot {
   use Cwd;
-  
+  #*&Simulation::Automate::PostProcessors::$subref(\$dataset,\$i,\$dataref1,\$flagsref,\$returnvalue,\$preprocref);
+  #&prepare_plot(@args);
   my $dataset=shift;
   $Simulation::Automate::PostProcLib::count=shift;
   my $dataref=shift;
   my $flagsref=shift;
-  my $verylast=shift;
-  # $Simulation::Automate::PostProcLib::verylast=shift;
-  
-  if($verylast!=1){
-    @Simulation::Automate::PostProcLib::results=@{$verylast};
+  my $verylastref=shift;
+
+  if($verylastref!=1){
+    @Simulation::Automate::PostProcLib::results=@{$verylastref};
     $Simulation::Automate::PostProcLib::verylast=0;
   } else {
     @Simulation::Automate::PostProcLib::results=();
@@ -101,59 +112,69 @@ sub prepare_plot {
 
   (my $batch,$Simulation::Automate::PostProcLib::interactive,my $nosims,$Simulation::Automate::PostProcLib::plot,my $verbose)=@{$flagsref};
   my $copy_results=1;
-  (my $nsims, my $simdataref,my $sweepedref,my $lastref)=@{$dataref};
+  #*my \$dataref1 = [\$nsims,\\\%data,\\\%sweepeddata,\\\%last];
+  (my $nsims, my $simdataref,my $current_set_valsref,my $lastref)=@{$dataref};
   
   %Simulation::Automate::PostProcLib::simdata=%{$simdataref};
-
-  my %sweeped=%{$sweepedref};
-$Simulation::Automate::PostProcLib::sweepvals='';
-foreach my $key (sort keys %sweeped) {
-  $Simulation::Automate::PostProcLib::sweepvals.="${key}-".$sweeped{$key}.'-';
-}
-$Simulation::Automate::PostProcLib::sweepvals=~s/-$//;
-  my @sweeped=sort keys %sweeped;
+#current_set_vals is actually "the current values in the sweep", so current_set_vals would a better name
+  my %current_set_vals=%{$current_set_valsref};
+  $Simulation::Automate::PostProcLib::sweepvals='';
+  foreach my $key (sort keys %current_set_vals) {
+    $Simulation::Automate::PostProcLib::sweepvals.="${key}-".$current_set_vals{$key}.'-';
+  }
+  $Simulation::Automate::PostProcLib::sweepvals=~s/-$//;
+  my @current_set_vals=sort keys %current_set_vals; # not used
+  %Simulation::Automate::PostProcLib::current_set_vals=%current_set_vals;
+  $Simulation::Automate::PostProcLib::current_set_valstr=$Simulation::Automate::PostProcLib::sweepvals;
+  $Simulation::Automate::PostProcLib::cond=$Simulation::Automate::PostProcLib::simdata{COND}||'<1';
   my $setvar=$Simulation::Automate::PostProcLib::simdata{SETVAR}||'none';
-  my $sweepval=${$Simulation::Automate::PostProcLib::simdata{$setvar}}[0];
+  $Simulation::Automate::PostProcLib::setvar=$setvar;
+  #  my $setvarval=${$Simulation::Automate::PostProcLib::simdata{$setvar}}[0]; # if SETVAR is defined, this would be the first value in the list for SETVAR. This is to used check if the last element in the SETVAR value list has been reached
+  my $setvarval=$Simulation::Automate::PostProcLib::simdata{$setvar}->[0]; # if SETVAR is defined, this would be the first value in the list for SETVAR. This is to used check if the last element in the SETVAR value list has been reached
 
-  my %last=%{$lastref};
-$Simulation::Automate::PostProcLib::last=($setvar ne 'none' && $sweepval==$last{$setvar});
+  my %last=%{$lastref}; # the last value in the list for every variable
+  $Simulation::Automate::PostProcLib::last=($setvar ne 'none' && $setvarval==$last{$setvar}); # SETVAR is defined and the element in the value list has been reached. 
 
   my $pattern=$Simulation::Automate::PostProcLib::simdata{OUTPUT_FILTER_PATTERN}|| '.*';
-my $devtype=$Simulation::Automate::PostProcLib::simdata{DEVTYPE};
-    my $ext=$Simulation::Automate::PostProcLib::simdata{TEMPL};
-$Simulation::Automate::PostProcLib::sweepvar=$Simulation::Automate::PostProcLib::simdata{SWEEPVAR}||'none';
-$Simulation::Automate::PostProcLib::normvar=$Simulation::Automate::PostProcLib::simdata{NORMVAR}||'none';
+  my $devtype=$Simulation::Automate::PostProcLib::simdata{DEVTYPE};
+  my $ext=$Simulation::Automate::PostProcLib::simdata{TEMPL};
+  $Simulation::Automate::PostProcLib::sweepvar=$Simulation::Automate::PostProcLib::simdata{SWEEPVAR}||'none';
+  $Simulation::Automate::PostProcLib::normvar=$Simulation::Automate::PostProcLib::simdata{NORMVAR}||'none';
+  $Simulation::Automate::PostProcLib::datacol=$Simulation::Automate::PostProcLib::simdata{DATACOL}||1;
+  $Simulation::Automate::PostProcLib::simtempl=$Simulation::Automate::PostProcLib::simdata{SIMTYPE};
+  $Simulation::Automate::PostProcLib::dirname= "${Simulation::Automate::PostProcLib::simtempl}-$dataset";
+  $Simulation::Automate::PostProcLib::anatempl=$Simulation::Automate::PostProcLib::simdata{ANALYSIS_TEMPLATE};
+  $Simulation::Automate::PostProcLib::results_file=$Simulation::Automate::PostProcLib::simtempl.'-'.$Simulation::Automate::PostProcLib::anatempl.'-'.$Simulation::Automate::PostProcLib::current_set_valstr.'.res';
+  $Simulation::Automate::PostProcLib::title=$Simulation::Automate::PostProcLib::simdata{TITLE}||"$devtype $Simulation::Automate::PostProcLib::simtempl simulation";
 
-$Simulation::Automate::PostProcLib::datacol=$Simulation::Automate::PostProcLib::simdata{DATACOL}||1;
-
-$Simulation::Automate::PostProcLib::simtempl=$Simulation::Automate::PostProcLib::simdata{SIMTYPE};
-$Simulation::Automate::PostProcLib::dirname= "${Simulation::Automate::PostProcLib::simtempl}-$dataset";
-$Simulation::Automate::PostProcLib::anatempl=$Simulation::Automate::PostProcLib::simdata{ANALYSIS_TEMPLATE};
-
-$Simulation::Automate::PostProcLib::title=$Simulation::Automate::PostProcLib::simdata{TITLE}||"$devtype $Simulation::Automate::PostProcLib::simtempl simulation";
-my $simtitle=$Simulation::Automate::PostProcLib::title;
-foreach my $key (keys %Simulation::Automate::PostProcLib::simdata) {
-($key!~/^_/) && next;
-($simtitle=~/$key/) && do {
-my $val=$Simulation::Automate::PostProcLib::simdata{$key};
-my $nicekey=$make_nice{$key}{title};
-my $niceval=$make_nice{$key}{${$val}[0]}||join(',',@{$val});
-$simtitle=~s/$key/$nicekey:\ $niceval/;
-};
-$Simulation::Automate::PostProcLib::title=$simtitle;
+  my $simtitle=$Simulation::Automate::PostProcLib::title;
+  foreach my $key (keys %Simulation::Automate::PostProcLib::simdata) {
+    ($key!~/^_/) && next;
+    ($simtitle=~/$key/) && do {
+      my $val=$Simulation::Automate::PostProcLib::simdata{$key};
+      my $nicekey=$make_nice{$key}{title}||&make_nice($key);
+      my $niceval=$make_nice{$key}{${$val}[0]}||join(',',@{$val});
+      $simtitle=~s/$key/$nicekey:\ $niceval/;
+    };
+    $Simulation::Automate::PostProcLib::title=$simtitle;
 }
-
-# XTICS, YTICS, XSTART, XSTOP, YSTART, YSTOP
+# For Gnuplot
+#XSTART, XSTOP, YSTART, YSTOP, XTICS, YTICS, YLABEL, XLABEL, LOGSCALE, STYLE,
+$Simulation::Automate::PostProcLib::xstart=$Simulation::Automate::PostProcLib::simdata{XSTART}||"";
+$Simulation::Automate::PostProcLib::xstop=$Simulation::Automate::PostProcLib::simdata{XSTOP}||"";
+$Simulation::Automate::PostProcLib::ystart=$Simulation::Automate::PostProcLib::simdata{YSTART}||"";
+$Simulation::Automate::PostProcLib::ystop=$Simulation::Automate::PostProcLib::simdata{YSTOP}||"";
+$Simulation::Automate::PostProcLib::xtics=$Simulation::Automate::PostProcLib::simdata{XTICS}||"";
+$Simulation::Automate::PostProcLib::ytics=$Simulation::Automate::PostProcLib::simdata{YTICS}||"";
 $Simulation::Automate::PostProcLib::ylabel=$Simulation::Automate::PostProcLib::simdata{YLABEL}||"$Simulation::Automate::PostProcLib::title";
 $Simulation::Automate::PostProcLib::xlabel=$Simulation::Automate::PostProcLib::simdata{XLABEL}||"$Simulation::Automate::PostProcLib::title";
 $Simulation::Automate::PostProcLib::logscale=($Simulation::Automate::PostProcLib::simdata{LOGSCALE})?"set nologscale xy\nset logscale ".lc($Simulation::Automate::PostProcLib::simdata{LOGSCALE}):'set nologscale xy';
-#STYLE
 $Simulation::Automate::PostProcLib::style=$Simulation::Automate::PostProcLib::simdata{STYLE}||'';
 
 $Simulation::Automate::PostProcLib::sweepvartitle=$Simulation::Automate::PostProcLib::xlabel||$make_nice{$Simulation::Automate::PostProcLib::sweepvar}{title}||$Simulation::Automate::PostProcLib::xlabel||$Simulation::Automate::PostProcLib::sweepvar;
-( $Simulation::Automate::PostProcLib::legendtitle, $Simulation::Automate::PostProcLib::legend)=@{&create_legend($Simulation::Automate::PostProcLib::sweepvals,\%make_nice)};
-
-}
+($Simulation::Automate::PostProcLib::legendtitle, $Simulation::Automate::PostProcLib::legend)=@{&create_legend($Simulation::Automate::PostProcLib::sweepvals,\%make_nice)};
+return [@_];
+} # END of prepare_plot()
 
 #------------------------------------------------------------------------------
 
@@ -165,7 +186,7 @@ open GNUPLOT,"| gnuplot $persist";
 print GNUPLOT $commands;
 close GNUPLOT;
 }
-}
+} # END of gnuplot()
 #------------------------------------------------------------------------------
 sub gnuplot_combined {
 my $firstplotline=shift;
@@ -207,10 +228,10 @@ eval('$plotline='.$plotlinetempl);
 push @lines, $plotline
 }
 $firstplotline=~s/set\s+key\s+title.*/set key title "$legendtitle"/;
+my $plot="\nplot ";
+if($firstplotline=~/$plot/ms){$plot=''};
+my $line=$firstplotline.$plot.join(",\\\n",@lines);
 
-my $line=$firstplotline."\nplot ".join(",\\\n",@lines);
-#carp "COMBINED: $line";
-#die;
 if($Simulation::Automate::PostProcLib::plot) {
 open GNUPLOT,"| gnuplot";
 print GNUPLOT $line;
@@ -221,7 +242,7 @@ print GNUPLOT $line;
 close GNUPLOT;
 
 if($Simulation::Automate::PostProcLib::interactive) {
-system("gv ${Simulation::Automate::PostProcLib::simtempl}-${Simulation::Automate::PostProcLib::anatempl}.ps &");
+system("ggv ${Simulation::Automate::PostProcLib::simtempl}-${Simulation::Automate::PostProcLib::anatempl}.ps &");
 }
 } # END of gnuplot_combined()
 #------------------------------------------------------------------------------
